import Foundation

struct Entry: Decodable, CustomDebugStringConvertible {
    let text: String
    
    public var debugDescription: String {
        return "\(text)"
    }
}

import Foundation

struct TextEntries {
    enum Key: String, CodingKey {
        case entries = "text_entries"
    }
    
    let values: [Entry]
}

extension TextEntries: Decodable {
    
    init(from decoder: Decoder) throws {
        let response = try decoder.container(keyedBy: Key.self)
        var entries = try response.nestedUnkeyedContainer(forKey: .entries)
        
        var values = [Entry]()
        while !entries.isAtEnd {
            let entry = try entries.decode(Entry.self)
            values.append(entry)
        }
        
        self.values = values
    }
}

var json = """
{
  "user": "qnoid",
  "created_at": "2021-01-19T18:47:01+0200",
  "text_entries": [{
      "text": "Hello!"
    },
    {
      "text": "¡Hola!"
    }
  ]
}
"""

let data = json.data(using: .utf8)!
let entries = try JSONDecoder().decode(TextEntries.self, from: data)

print(entries.values.map { entry in
    entry.text
})

